@@ -101,10 +101,16 @@ def remove_stop_key(
     if stop_keys is None:
         stop_keys = config.STOP_KEYS
 
+    text = text.strip()
+
     for stop_key in stop_keys:
         if text.endswith(stop_key):
             text = text.rstrip(stop_key)
 
+            text = text.strip()
+
+            break
+
     return text
 
 
@@ -174,8 +180,25 @@ def normalize(
     return text.replace(':.', ':').strip()
 
 
-def max_chars_limit(text: str, max_chars: int):
-    return text[0: max_chars]
+def take(text: str, limit: int, strip=True):
+    if limit == 0:
+        raise ValueError('take limit cannot be 0!')
+
+    if limit > len(text):
+        return text
+
+    text = text[0: limit]
+
+    return text.strip() if strip else text
+
+
+def skip(text: str, limit: int, strip=True):
+    if limit > len(text):
+        return ''
+
+    text = text[limit:]
+
+    return text.strip() if strip else text
 
 
 def remove_inline_breaks(
@@ -269,10 +292,10 @@ def to_str(
         default: Optional[str] = ''
 ):
 
-    if not value:
+    if value is None:
         return default
 
-    if isinstance(value, (int, float)):
+    if isinstance(value, (int, float, bool)):
         value = str(value)
 
     return value
